@@ -36,18 +36,6 @@ lsmeans.default = function(object, specs, ...) {
     do.call("lsmeans", lsargs)###lsmeans(RG, specs, ...)
 }
 
-# signature = (ALL, ALL) <==> (some model object, ALL)
-# Look for args: at, cov.reduce = mean, mult.levs
-# lsmeans = function(object, specs, ...) {
-#     rgargs = .args.for.fcn(ref.grid, list(object=object, ...))
-#     RG = do.call("ref.grid", rgargs)
-#     lsargs = list(object = RG, specs = specs, ...)
-#     for (nm in names(rgargs)[-1]) lsargs[[nm]] = NULL
-#     do.call("lsmeans", lsargs)###lsmeans(RG, specs, ...)
-# }
-# setGeneric("lsmeans")
-
-#setMethod("lsmeans", signature(object="ANY", specs="formula"),
 lsmeans.formula =
 function(object, specs, contr.list, trend, ...) {
     if (!missing(trend))
@@ -73,7 +61,6 @@ function(object, specs, contr.list, trend, ...) {
 }
 
 # List of specs
-#setMethod("lsmeans", signature(object="ANY", specs="list"),
 lsmeans.list = function(object, specs, ...) {
     result = list()
     nms = names(specs)
@@ -126,16 +113,54 @@ lsmeans.character.default = function(object, specs, ...)
     lsmeans.default(object, specs, ...)
 
 # Method for a ref.grid -- all methods will get us here eventually
-#setMethod("lsmeans", signature(object="ref.grid", specs="character"), 
 lsmeans.character.ref.grid = function(object, specs, by = NULL, 
          fac.reduce = function(coefs) apply(coefs, 2, mean), 
-         contr, options = getOption("lsmeans")$lsmeans, ...) {
+         contr, options = getOption("lsmeans")$lsmeans, weights, ...) {
     RG = object
     facs = union(specs, by)
     
     # Figure out the structure of the grid
+    freq = RG@grid[[".freq."]]
     dims = sapply(RG@levels, length)
     row.idx = array(seq_len(nrow(RG@linfct)), dims)
+    use.mars = match(facs, names(RG@levels)) # which margins to use
+    avgd.mars = setdiff(seq_along(dims)[dims>1], use.mars) # margins that we average over
+    
+    # Reconcile weights, if there are any margins left
+    if ((length(avgd.mars) > 0) && !missing(weights)) {
+        if (is.character(weights)) {
+            if (is.null(freq))
+                message("Frequency information not available -- deferring to fac.reduce")
+            else {
+                wopts = c("equal","proportional","outer","cells","invalid")
+                weights = switch(wopts[pmatch(weights, wopts, 5)],
+                    equal = rep(1, prod(dims[avgd.mars])),
+                    proportional = as.numeric(plyr::aaply(row.idx, avgd.mars,
+                                                          function(idx) sum(freq[idx]))),
+                    outer = {
+                        ftbl = plyr::aaply(row.idx, avgd.mars,
+                                           function(idx) sum(freq[idx]), .drop = FALSE)
+                        w = N = sum(ftbl)
+                        for (d in seq_along(dim(ftbl)))
+                            w = outer(w, plyr::aaply(ftbl, d, sum) / N)
+                        as.numeric(w)
+                    },
+                    cells = "fq",
+                    invalid = stop("Invalid 'weights' option: '", weights, "'")
+                )
+            }
+        }
+        if (is.numeric(weights)) {
+            wtmat = diag(weights)
+            wtsum = sum(weights)
+            if (wtsum <= 1e-8) wtsum = NA
+            fac.reduce = function(coefs) {
+                if (nrow(coefs) != nrow(wtmat))
+                    stop("Nonconforming number of weights -- need ", nrow(coefs))
+                apply(wtmat %*% coefs, 2, sum) / wtsum
+            }
+        }
+    }
     
     # Get the required factor combs
     levs = list()
@@ -145,9 +170,15 @@ lsmeans.character.ref.grid = function(object, specs, by = NULL,
             stop(paste("No variable named", f, "in the reference grid"))
     }
     combs = do.call("expand.grid", levs)
-    K = plyr::alply(row.idx, match(facs, names(RG@levels)), function(idx) {
-        fac.reduce(RG@linfct[idx, , drop=FALSE])
-    })
+    if (!missing(weights) && (weights == "fq"))
+        K = plyr::alply(row.idx, use.mars, function(idx) {
+            fq = RG@grid[[".freq."]][idx]
+            apply(diag(fq) %*% RG@linfct[idx, , drop=FALSE], 2, sum) / sum(fq)
+        })
+    else
+        K = plyr::alply(row.idx, use.mars, function(idx) {
+            fac.reduce(RG@linfct[idx, , drop=FALSE])
+        })
         
     linfct = t(as.matrix(as.data.frame(K)))
     row.names(linfct) = NULL
@@ -157,16 +188,17 @@ lsmeans.character.ref.grid = function(object, specs, by = NULL,
     
     # Figure offset, if any
     if (".offset." %in% names(RG@grid)) {
-        offset = plyr::alply(row.idx, match(facs, names(RG@levels)), function(idx) {
-            fac.reduce(RG@grid[idx, ".offset.", drop=FALSE])
-        })
-        combs[[".offset."]] = unlist(offset)
+        combs[[".offset."]] = as.numeric(plyr::aaply(row.idx, use.mars, function(idx)
+            fac.reduce(as.matrix(RG@grid[idx, ".offset.", drop=FALSE]))))
     }
     
-    # Figure out which factors have been averaged over
-    nlev = sapply(RG@levels, length)
-    avgd.over = setdiff(names(nlev[nlev > 1]), facs)
+    avgd.over = names(RG@levels[avgd.mars])
     
+    # Update .freq column of grid, if it exists
+    if (!is.null(freq)) {
+        combs[[".freq."]] = as.numeric(plyr::aaply(row.idx, use.mars, 
+            function(idx) sum(freq[idx])))
+    }
     
     RG@roles$responses = character()
     RG@misc$famSize = nrow(linfct)
@@ -215,7 +247,8 @@ contrast = function(object, ...)
 contrast.ref.grid = function(object, method = "eff", by, adjust, 
         options = getOption("lsmeans")$contrast, ...) {
     args = object@grid
-    args[[".offset."]] = NULL # ignore the offset in labels, etc.
+    args[[".offset."]] = NULL 
+    args[[".freq."]] = NULL # ignore auxiliary stuff in labels, etc.
     if(missing(by)) 
         by = object@misc$by.vars
     if (!is.null(by)) {
